# Django-invitations - Generic invitations app

[![Jazzband](https://jazzband.co/static/img/badge.svg)](https://jazzband.co/)
[![PyPI Download](https://img.shields.io/pypi/v/django-invitations.svg)](https://pypi.python.org/pypi/django-invitations)
[![PyPI Python Versions](https://img.shields.io/pypi/pyversions/django-invitations.svg)](https://pypi.python.org/pypi/django-invitations)
[![Build status](https://github.com/jazzband/django-invitations/actions/workflows/test.yml/badge.svg)](https://github.com/jazzband/django-invitations/actions/workflows/test.yml)
[![Coverage status](https://codecov.io/gh/jazzband/django-invitations/branch/master/graph/badge.svg?token=xxufPt4r3I)](https://codecov.io/gh/jazzband/django-invitations)
[![Documentation Status](https://readthedocs.org/projects/django-invitations/badge/?version=latest)](https://django-invitations.readthedocs.io/en/latest/?badge=latest)

## About

Generic invitations solution with adaptable backend and support for django-allauth.

## Contributing

As we are members of a [JazzBand project](https://jazzband.co/projects), `django-invitations` contributors should adhere to the [Contributor Code of Conduct](https://jazzband.co/about/conduct).

### Documentation

Documentation can be found at https://django-invitations.readthedocs.io/
